@@ -42,7 +42,6 @@
 #include <totem-private.h>
 
 #include <totem-time-helpers.h>
-#include <totem-rtl-helpers.h>
 
 #include "totem-grilo.h"
 #include "totem-search-entry.h"
@@ -1860,7 +1859,7 @@ setup_source_switcher (TotemGrilo *self)
 
 	self->priv->switcher = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 
-	self->priv->recent = create_switcher_button (self, _("Recent"), "recent");
+	self->priv->recent = create_switcher_button (self, _("Videos"), "recent");
 	gtk_container_add (GTK_CONTAINER (self->priv->switcher), self->priv->recent);
 
 	g_signal_connect (G_OBJECT (self->priv->recent), "drag_data_received",
@@ -2091,6 +2090,7 @@ delete_foreach (gpointer data,
 	path = gtk_tree_row_reference_get_path (ref);
 	if (!path || !gtk_tree_model_get_iter (view_model, &iter, path)) {
 		g_warning ("An item that was scheduled for removal isn't available any more");
+		gtk_tree_row_reference_free (ref);
 		return;
 	}
 
@@ -2150,6 +2150,7 @@ delete_foreach (gpointer data,
 end:
 	g_clear_object (&media);
 	g_clear_object (&source);
+	gtk_tree_row_reference_free (ref);
 }
 
 static void
@@ -2173,7 +2174,6 @@ delete_cb (TotemSelectionToolbar *bar,
 		l->data = ref;
 	}
 	g_list_foreach (list, delete_foreach, model);
-	g_list_free_full (list, (GDestroyNotify) gtk_tree_row_reference_free);
 
 	g_signal_handlers_unblock_by_func (self->priv->browser, "view-selection-changed", self);
 
@@ -2184,6 +2184,7 @@ static void
 setup_browse (TotemGrilo *self)
 {
 	GtkAdjustment *adj;
+	const char const * select_all_accels[] = { "<Primary>A", NULL };
 
 	/* Search */
 	gtk_search_bar_connect_entry (GTK_SEARCH_BAR (self->priv->search_bar),
@@ -2204,7 +2205,7 @@ setup_browse (TotemGrilo *self)
 	g_signal_connect (G_OBJECT (self->priv->select_all_action), "activate",
 			  G_CALLBACK (select_all_action_cb), self);
 	g_action_map_add_action (G_ACTION_MAP (self->priv->totem), G_ACTION (self->priv->select_all_action));
-	gtk_application_add_accelerator (GTK_APPLICATION (self->priv->totem), "<Primary>A", "app.select-all", NULL);
+	gtk_application_set_accels_for_action (GTK_APPLICATION (self->priv->totem), "app.select-all", select_all_accels);
 	g_object_bind_property (self->priv->header, "select-mode",
 				self->priv->select_all_action, "enabled",
 				G_BINDING_SYNC_CREATE);
