@@ -37,12 +37,6 @@
 
 #include "totem-profile.h"
 
-/* Callback functions for GtkBuilder */
-G_MODULE_EXPORT void play_action_callback (GtkAction *action, Totem *totem);
-G_MODULE_EXPORT void next_chapter_action_callback (GtkAction *action, Totem *totem);
-G_MODULE_EXPORT void previous_chapter_action_callback (GtkAction *action, Totem *totem);
-G_MODULE_EXPORT void clear_playlist_action_callback (GtkAction *action, Totem *totem);
-
 static void
 open_action_cb (GSimpleAction *action,
 		GVariant      *parameter,
@@ -249,6 +243,30 @@ select_subtitle_action_cb (GSimpleAction *action,
 					       TOTEM_PLAYLIST_DIALOG_PLAYING);
 }
 
+static void
+play_action_cb (GSimpleAction *action,
+		GVariant      *parameter,
+		gpointer       user_data)
+{
+	totem_object_play_pause (TOTEM_OBJECT (user_data));
+}
+
+static void
+next_chapter_action_cb (GSimpleAction *action,
+			GVariant      *parameter,
+			gpointer       user_data)
+{
+	TOTEM_PROFILE (totem_object_seek_next (TOTEM_OBJECT (user_data)));
+}
+
+static void
+previous_chapter_action_cb (GSimpleAction *action,
+			    GVariant      *parameter,
+			    gpointer       user_data)
+{
+	TOTEM_PROFILE (totem_object_seek_previous (TOTEM_OBJECT (user_data)));
+}
+
 static GActionEntry app_entries[] = {
 	/* Main app menu */
 	{ "open", open_action_cb, NULL, NULL, NULL },
@@ -274,12 +292,18 @@ static GActionEntry app_entries[] = {
 	{ "zoom", toggle_action_cb, NULL, "false", zoom_action_change_state },
 	{ "next-angle", next_angle_action_cb, NULL, NULL, NULL },
 	{ "eject", eject_action_cb, NULL, NULL, NULL },
+
+	/* Navigation popup */
+	{ "play", play_action_cb, NULL, NULL, NULL },
+	{ "next-chapter", next_chapter_action_cb, NULL, NULL, NULL },
+	{ "previous-chapter", previous_chapter_action_cb, NULL, NULL, NULL },
 };
 
 void
 totem_app_menu_setup (Totem *totem)
 {
 	GMenuModel *appmenu;
+	char *accels[] = { NULL, NULL };
 
 	g_action_map_add_action_entries (G_ACTION_MAP (totem), app_entries, G_N_ELEMENTS (app_entries), totem);
 
@@ -287,11 +311,12 @@ totem_app_menu_setup (Totem *totem)
 	gtk_application_set_app_menu (GTK_APPLICATION (totem), appmenu);
 
 	/* FIXME: https://bugzilla.gnome.org/show_bug.cgi?id=700085 */
-	gtk_application_add_accelerator (GTK_APPLICATION (totem), "<Primary>G", "app.next-angle", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (totem), "<Primary>M", "app.root-menu", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (totem), "<Primary>P", "app.properties", NULL);
-	gtk_application_add_accelerator (GTK_APPLICATION (totem), "<Primary>E", "app.eject", NULL);
-
+	accels[0] = "<Primary>G";
+	gtk_application_set_accels_for_action (GTK_APPLICATION (totem), "app.next-angle", (const char * const *) accels);
+	accels[0] = "<Primary>M";
+	gtk_application_set_accels_for_action (GTK_APPLICATION (totem), "app.root-menu", (const char * const *) accels);
+	accels[0] = "<Primary>E";
+	gtk_application_set_accels_for_action (GTK_APPLICATION (totem), "app.eject", (const char * const *) accels);
 	gtk_window_set_application (GTK_WINDOW (totem->win), GTK_APPLICATION (totem));
 }
 
@@ -497,37 +522,3 @@ totem_sublang_exit (Totem *totem)
 	g_list_free_full (totem->subtitles_list, g_free);
 	g_list_free_full (totem->languages_list, g_free);
 }
-
-void
-play_action_callback (GtkAction *action, Totem *totem)
-{
-	totem_object_play_pause (totem);
-}
-
-void
-next_chapter_action_callback (GtkAction *action, Totem *totem)
-{
-	TOTEM_PROFILE (totem_object_seek_next (totem));
-}
-
-void
-previous_chapter_action_callback (GtkAction *action, Totem *totem)
-{
-	TOTEM_PROFILE (totem_object_seek_previous (totem));
-}
-
-void
-clear_playlist_action_callback (GtkAction *action, Totem *totem)
-{
-	totem_playlist_clear (totem->playlist);
-	totem_object_set_mrl (totem, NULL, NULL);
-}
-
-void
-totem_ui_manager_setup (Totem *totem)
-{
-	totem->main_action_group = GTK_ACTION_GROUP (gtk_builder_get_object (totem->xml, "main-action-group"));
-
-	totem->ui_manager = GTK_UI_MANAGER (gtk_builder_get_object (totem->xml, "totem-ui-manager"));
-}
-
